==> Evergreen-ILS-3.15.9.tar.gz: Evergreen-ILS-3.15.9/Open-ILS/web/js/dojo/openils/actor/nls/oc-fr/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "DIFUSION",
    ":DELETE_ADDRESS": "Suprimir l'adre\u00e7a ${0}?",
    ":NEED_ADDRESS": "Una adre\u00e7a es requesida al moment de l'inscripcion.",
    ":DUPE_PATRON_NAME": "Trobat ${0} client(s) amb lo meteis nom",
    ":DUPE_PATRON_EMAIL": "Trobat ${0} client(s) amb lo meteis corri\u00e8l",
    ":DUPE_PATRON_IDENT": "Trobat ${0} client(s) amb la meteissa identificacion",
    ":DUPE_PATRON_PHONE": "Trobat ${0} client(s) amb lo meteis num\u00e8ro de telef\u00f2n",
    ":DUPE_PATRON_ADDR": "Trobat ${0} client(s) amb la meteissa adre\u00e7a",
    ":REPLACED_ADDRESS": "Replaces address ${0}<br/> ${1} ${2}<br/> ${3}, ${4} ${5}",
    ":INVALID_FORM": "Lo formulari es pas valid. Merc\u00e9 de lo modificar e ensajatz tornarmai.",
    ":EXAMPLE": "Exemple : ",
    ":REPLACE_BARCODE": "Rempla\u00e7ar lo c\u00f2de de barras",
    ":BARCODE_IN_USE": "Lo c\u00f2de de barras es ja utilizat",
    ":SEE_ALL": "Veire tot",
    ":DUPE_USERNAME": "Nom d\u2019utilizaire ja utilizat",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "Verificar lo senhal",
    ":PARENT_OR_GUARDIAN": "Parent/tutor",
    ":USER_SETTINGS": "Param\u00e8tres de l'utilizaire",
    ":ADDRESS_HEADER": "Adre\u00e7a",
    ":ADDRESS_MAILING": "Mandad\u00eds",
    ":ADDRESS_BILLING": "Facturacion",
    ":ADDRESS_PENDING": "S\u2019ag\u00eds d\u2019una adre\u00e7a en esp\u00e8ra : ",
    ":ADDRESS_APPROVE": "Adre\u00e7a aprovada",
    ":ADDRESS_OWNED": "Aquesta adre\u00e7a aparten a un autre utilizaire : ",
    ":ADDRESS_NEW": "Adre\u00e7a nov\u00e8la",
    ":STAT_CATS": "Categorias estatisticas",
    ":SAVE": "Enregistrar",
    ":SAVE_CLONE": "Salvar &amp; Clonar",
    ":SHOW_REQUIRED": "Far veire sonque los camps obligat\u00f2ris",
    ":SHOW_SUGGESTED": "Far veire los camps suggerits",
    ":SHOW_ALL": "Far veire totes los camps",
    ":ALL_CARDS_BARCODE": "C\u00f2de de barras",
    ":ALL_CARDS_ACTIVE": "Activa",
    ":ALL_CARDS_PRIMARY": "Principal",
    ":ALL_CARDS_CLOSE": "Tampar",
    ":ALL_CARDS_APPLY": "Aplicar los cambiaments",
    ":INVALIDATE": "Invalidar",
    ":HOLD_NOTIFY_PHONE": "Telef\u00f2n\u00a0: ",
    ":HOLD_NOTIFY_EMAIL": "Adre\u00e7a electronica\u00a0: ",
    ":HOLD_NOTIFY_SMS": "SMS : ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}

==> Evergreen-ILS-3.16.1.tar.gz: Evergreen-ILS-3.16.1/Open-ILS/web/js/dojo/openils/actor/nls/oc-fr/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "DIFUSION",
    ":DELETE_ADDRESS": "Suprimir l'adre\u00e7a ${0}?",
    ":NEED_ADDRESS": "Una adre\u00e7a es requesida al moment de l'inscripcion.",
    ":DUPE_PATRON_NAME": "Trobat ${0} client(s) amb lo meteis nom",
    ":DUPE_PATRON_EMAIL": "Trobat ${0} client(s) amb lo meteis corri\u00e8l",
    ":DUPE_PATRON_IDENT": "Trobat ${0} client(s) amb la meteissa identificacion",
    ":DUPE_PATRON_PHONE": "Trobat ${0} client(s) amb lo meteis num\u00e8ro de telef\u00f2n",
    ":DUPE_PATRON_ADDR": "Trobat ${0} client(s) amb la meteissa adre\u00e7a",
    ":REPLACED_ADDRESS": "<div>Rempla\u00e7a l'adre\u00e7a <b>${0}</b><br/> ${1} ${2}<br/> ${3}, ${4} ${5}</div>",
    ":INVALID_FORM": "Lo formulari es pas valid. Merc\u00e9 de lo modificar e ensajatz tornarmai.",
    ":EXAMPLE": "Exemple : ",
    ":REPLACE_BARCODE": "Rempla\u00e7ar lo c\u00f2de de barras",
    ":BARCODE_IN_USE": "Lo c\u00f2de de barras es ja utilizat",
    ":SEE_ALL": "Veire tot",
    ":DUPE_USERNAME": "Nom d\u2019utilizaire ja utilizat",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "Verificar lo senhal",
    ":PARENT_OR_GUARDIAN": "Parent/tutor",
    ":PARENT_OR_GUARDIAN_EMAIL": "Parent/Guardian Email",
    ":USER_SETTINGS": "Param\u00e8tres de l'utilizaire",
    ":ADDRESS_HEADER": "Adre\u00e7a",
    ":ADDRESS_MAILING": "Mandad\u00eds",
    ":ADDRESS_BILLING": "Facturacion",
    ":ADDRESS_PENDING": "S\u2019ag\u00eds d\u2019una adre\u00e7a en esp\u00e8ra : ",
    ":ADDRESS_APPROVE": "Adre\u00e7a aprovada",
    ":ADDRESS_OWNED": "Aquesta adre\u00e7a aparten a un autre utilizaire : ",
    ":ADDRESS_NEW": "Adre\u00e7a nov\u00e8la",
    ":STAT_CATS": "Categorias estatisticas",
    ":SAVE": "Enregistrar",
    ":SAVE_CLONE": "Salvar &amp; Clonar",
    ":SHOW_REQUIRED": "Far veire sonque los camps obligat\u00f2ris",
    ":SHOW_SUGGESTED": "Far veire los camps suggerits",
    ":SHOW_ALL": "Far veire totes los camps",
    ":ALL_CARDS_BARCODE": "C\u00f2de de barras",
    ":ALL_CARDS_ACTIVE": "Activa",
    ":ALL_CARDS_PRIMARY": "Principal",
    ":ALL_CARDS_CLOSE": "Tampar",
    ":ALL_CARDS_APPLY": "Aplicar los cambiaments",
    ":INVALIDATE": "Invalidar",
    ":HOLD_NOTIFY_PHONE": "Telef\u00f2n\u00a0: ",
    ":HOLD_NOTIFY_EMAIL": "Adre\u00e7a electronica\u00a0: ",
    ":HOLD_NOTIFY_SMS": "SMS : ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}
